==> maven-pdf-plugin-1.6.1-source-release.zip: maven-pdf-plugin-1.6.1/src/main/java/org/apache/maven/plugins/pdf/AbstractPdfMojo.java <==
package org.apache.maven.plugins.pdf;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.File;
import java.io.IOException;

import org.apache.maven.plugin.AbstractMojo;

/**
 * Common code to create pdf, either module pdf or reactor aggregate.
 * 
 * @since 1.5
 */
public abstract class AbstractPdfMojo
    extends AbstractMojo
{
    protected abstract File getOutputDirectory();
    protected abstract File getWorkingDirectory();
    protected abstract boolean isIncludeReports();

    /**
     * The temp Site dir to have all site and generated-site files.
     *
     * @since 1.1
     */
    private File siteDirectoryTmp;

    protected abstract void prepareTempSiteDirectory( final File tmpSiteDir )
        throws IOException;

    /**
     * @return the default tmpSiteDirectory.
     * @throws IOException if any
     * @since 1.1
     */
    protected File getSiteDirectoryTmp()
        throws IOException
    {
        if ( this.siteDirectoryTmp == null )
        {
            final File tmpSiteDir = new File( getWorkingDirectory(), "site.tmp" );
            prepareTempSiteDirectory( tmpSiteDir );

            this.siteDirectoryTmp = tmpSiteDir;
        }

        return this.siteDirectoryTmp;
    }

}

==> maven-pdf-plugin-1.6.2-source-release.zip: maven-pdf-plugin-1.6.2/src/main/java/org/apache/maven/plugins/pdf/AbstractPdfMojo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.plugins.pdf;

import java.io.File;
import java.io.IOException;

import org.apache.maven.plugin.AbstractMojo;

/**
 * Common code to create pdf, either module pdf or reactor aggregate.
 *
 * @since 1.5
 */
public abstract class AbstractPdfMojo extends AbstractMojo {
    protected abstract File getOutputDirectory();

    protected abstract File getWorkingDirectory();

    protected abstract boolean isIncludeReports();

    /**
     * The temp Site dir to have all site and generated-site files.
     *
     * @since 1.1
     */
    private File siteDirectoryTmp;

    protected abstract void prepareTempSiteDirectory(File tmpSiteDir) throws IOException;

    /**
     * @return the default tmpSiteDirectory.
     * @throws IOException if any
     * @since 1.1
     */
    protected File getSiteDirectoryTmp() throws IOException {
        if (this.siteDirectoryTmp == null) {
            final File tmpSiteDir = new File(getWorkingDirectory(), "site.tmp");
            prepareTempSiteDirectory(tmpSiteDir);

            this.siteDirectoryTmp = tmpSiteDir;
        }

        return this.siteDirectoryTmp;
    }
}
